@@ -19,9 +19,15 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
+#if !defined (__LIBEDATA_CAL_H_INSIDE__) && !defined (LIBEDATA_CAL_COMPILATION)
+#error "Only <libedata-cal/libedata-cal.h> should be included directly."
+#endif
+
 #ifndef E_CAL_BACKEND_UTIL_H
 #define E_CAL_BACKEND_UTIL_H
 
+#include <libedataserver/libedataserver.h>
+
 #include <libedata-cal/e-cal-backend.h>
 
 G_BEGIN_DECLS
@@ -31,12 +37,15 @@ G_BEGIN_DECLS
  */
 
 gboolean	e_cal_backend_mail_account_get_default
-						(gchar **address,
+						(ESourceRegistry *registry,
+						 gchar **address,
 						 gchar **name);
 gboolean	e_cal_backend_mail_account_is_valid
-						(gchar *user,
+						(ESourceRegistry *registry,
+						 gchar *user,
 						 gchar **name);
-gboolean	e_cal_backend_user_declined	(icalcomponent *icalcomp);
+gboolean	e_cal_backend_user_declined	(ESourceRegistry *registry,
+                                                 icalcomponent *icalcomp);
 
 G_END_DECLS
 
