@@ -1459,8 +1459,8 @@ dump_fi (CamelFolderInfo *fi,
 	s[depth] = 0;
 
 	while (fi) {
-		printf("%sfull_name: %s\n", s, fi->full_name);
-		printf("%sflags: %08x\n", s, fi->flags);
+		printf ("%sfull_name: %s\n", s, fi->full_name);
+		printf ("%sflags: %08x\n", s, fi->flags);
 		dump_fi (fi->child, depth + 2);
 		fi = fi->next;
 	}
@@ -1567,14 +1567,14 @@ folder_info_cmp (gconstpointer ap,
 /**
  * camel_folder_info_build:
  * @folders: an array of #CamelFolderInfo
- * @namespace: an ignorable prefix on the folder names
+ * @namespace_: an ignorable prefix on the folder names
  * @separator: the hieararchy separator character
  * @short_names: %TRUE if the (short) name of a folder is the part after
  * the last @separator in the full name. %FALSE if it is the full name.
  *
  * This takes an array of folders and attaches them together according
  * to the hierarchy described by their full_names and @separator. If
- * @namespace is non-%NULL, then it will be ignored as a full_name
+ * @namespace_ is non-%NULL, then it will be ignored as a full_name
  * prefix, for purposes of comparison. If necessary,
  * camel_folder_info_build() will create additional #CamelFolderInfo with
  * %NULL urls to fill in gaps in the tree. The value of @short_names
@@ -1587,7 +1587,7 @@ folder_info_cmp (gconstpointer ap,
  **/
 CamelFolderInfo *
 camel_folder_info_build (GPtrArray *folders,
-                         const gchar *namespace,
+                         const gchar *namespace_,
                          gchar separator,
                          gboolean short_names)
 {
@@ -1596,9 +1596,9 @@ camel_folder_info_build (GPtrArray *folders,
 	gchar *p, *pname;
 	gint i, nlen;
 
-	if (!namespace)
-		namespace = "";
-	nlen = strlen (namespace);
+	if (namespace_ == NULL)
+		namespace_ = "";
+	nlen = strlen (namespace_);
 
 	qsort (folders->pdata, folders->len, sizeof (folders->pdata[0]), folder_info_cmp);
 
@@ -1612,7 +1612,7 @@ camel_folder_info_build (GPtrArray *folders,
 	/* Now find parents. */
 	for (i = 0; i < folders->len; i++) {
 		fi = folders->pdata[i];
-		if (!strncmp (namespace, fi->full_name, nlen)
+		if (!strncmp (namespace_, fi->full_name, nlen)
 		    && (p = strrchr (fi->full_name + nlen, separator))) {
 			pname = g_strndup (fi->full_name, p - fi->full_name);
 			pfi = g_hash_table_lookup (hash, pname);
@@ -2075,21 +2075,21 @@ camel_store_get_folder_info_sync (CamelStore *store,
 	if (info && (top == NULL || *top == '\0') && (flags & CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL) == 0) {
 		if (store->flags & CAMEL_STORE_VTRASH)
 			/* the name of the Trash folder, used for deleted messages */
-			add_special_info (store, info, CAMEL_VTRASH_NAME, _("Trash"), FALSE, CAMEL_FOLDER_VIRTUAL|CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_VTRASH|CAMEL_FOLDER_TYPE_TRASH);
+			add_special_info (store, info, CAMEL_VTRASH_NAME, _("Trash"), FALSE, CAMEL_FOLDER_VIRTUAL | CAMEL_FOLDER_SYSTEM | CAMEL_FOLDER_VTRASH | CAMEL_FOLDER_TYPE_TRASH);
 		if (store->flags & CAMEL_STORE_VJUNK)
 			/* the name of the Junk folder, used for spam messages */
-			add_special_info (store, info, CAMEL_VJUNK_NAME, _("Junk"), TRUE, CAMEL_FOLDER_VIRTUAL|CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_VTRASH|CAMEL_FOLDER_TYPE_JUNK);
+			add_special_info (store, info, CAMEL_VJUNK_NAME, _("Junk"), TRUE, CAMEL_FOLDER_VIRTUAL | CAMEL_FOLDER_SYSTEM | CAMEL_FOLDER_VTRASH | CAMEL_FOLDER_TYPE_JUNK);
 	} else if (!info && top && (flags & CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL) == 0) {
 		CamelFolderInfo *root_info = NULL;
 
 		if ((store->flags & CAMEL_STORE_VTRASH) != 0 && g_str_equal (top, CAMEL_VTRASH_NAME)) {
 			root_info = class->get_folder_info_sync (store, NULL, flags & (~CAMEL_STORE_FOLDER_INFO_RECURSIVE), cancellable, error);
 			if (root_info)
-				add_special_info (store, root_info, CAMEL_VTRASH_NAME, _("Trash"), FALSE, CAMEL_FOLDER_VIRTUAL|CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_VTRASH|CAMEL_FOLDER_TYPE_TRASH);
+				add_special_info (store, root_info, CAMEL_VTRASH_NAME, _("Trash"), FALSE, CAMEL_FOLDER_VIRTUAL | CAMEL_FOLDER_SYSTEM | CAMEL_FOLDER_VTRASH | CAMEL_FOLDER_TYPE_TRASH);
 		} else if ((store->flags & CAMEL_STORE_VJUNK) != 0 && g_str_equal (top, CAMEL_VJUNK_NAME)) {
 			root_info = class->get_folder_info_sync (store, NULL, flags & (~CAMEL_STORE_FOLDER_INFO_RECURSIVE), cancellable, error);
 			if (root_info)
-				add_special_info (store, root_info, CAMEL_VJUNK_NAME, _("Junk"), TRUE, CAMEL_FOLDER_VIRTUAL|CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_VTRASH|CAMEL_FOLDER_TYPE_JUNK);
+				add_special_info (store, root_info, CAMEL_VJUNK_NAME, _("Junk"), TRUE, CAMEL_FOLDER_VIRTUAL | CAMEL_FOLDER_SYSTEM | CAMEL_FOLDER_VTRASH | CAMEL_FOLDER_TYPE_JUNK);
 		}
 
 		if (root_info) {
@@ -2104,7 +2104,7 @@ camel_store_get_folder_info_sync (CamelStore *store,
 
 	camel_operation_pop_message (cancellable);
 
-	if (camel_debug_start("store:folder_info")) {
+	if (camel_debug_start ("store:folder_info")) {
 		const gchar *uid;
 
 		uid = camel_service_get_uid (CAMEL_SERVICE (store));
@@ -2873,7 +2873,7 @@ camel_store_rename_folder_sync (CamelStore *store,
 				folder = folders->pdata[i];
 				full_name = camel_folder_get_full_name (folder);
 
-				new = g_strdup_printf("%s%s", new_name, full_name + strlen(old_name));
+				new = g_strdup_printf ("%s%s", new_name, full_name + strlen (old_name));
 				camel_object_bag_rekey (store->folders, folder, new);
 				camel_folder_rename (folder, new);
 				g_free (new);
