@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 #include <stdlib.h>
-#include <libecal/e-cal.h>
+#include <libecal/libecal.h>
 #include <libical/ical.h>
 
 #include "ecal-test-utils.h"
@@ -48,7 +48,6 @@ main (gint argc,
 	g_assert (!g_strcmp0 (icaltimezone_get_tznames (zone),
 			icaltimezone_get_tznames (zone_final)));
 
-	ecal_test_utils_cal_remove (cal);
 	icaltimezone_free (zone, TRUE);
 
 	return 0;
