@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
 #include <stdlib.h>
-#include <libecal/e-cal.h>
+#include <libecal/libecal.h>
 
 #include "ecal-test-utils.h"
 
@@ -55,7 +55,5 @@ main (gint argc,
 
 	g_main_loop_run (loop);
 
-	ecal_test_utils_cal_remove (cal);
-
 	return 0;
 }
